==> antiright-2.99.8.tar.bz2: antiright-2.99.8/gtkshell/updated_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

static void
gsh_test_updating(struct GSH * gsh)
{
	ARPASSERT(gsh);
	if((gsh->bflags & GSH_UPDATING) != GSH_UPDATING)
	{
		gsh_start_updates(gsh);
		gsh->bflags |= GSH_UPDATING;
	}

}

static void
gsh_updater_argument_generic(struct GSH * gsh, int argc, int *counter)
{
	gsh_count(argc, counter);
	gsh_test_updating(gsh);
}

static void
add_updater(struct GSH * gsh, int argc, int * counter, char **argv,
		   void (*add_func)(struct GSH *, const gchar *))
{
	ARBUG("enter add_updater");
	(*add_func)(gsh, (const gchar *)argv[*counter+1]);
	gsh_updater_argument_generic(gsh, argc, counter);
	ARBUG("leave add_updater");
}

void
gsh_handle_updated_arguments(struct GSH * gsh, int argc,
			     char **argv, int *counter)
{
	g_assert(strlen(argv[(*counter)]) > 2);
	switch (argv[(*counter)][3])
	{
	case 'l':
		add_updater(gsh, argc, counter, argv,
			    &gsh_add_updated_label);
		break;
	case 'p':
		add_updater(gsh, argc, counter, argv,
			    &gsh_add_updated_progress);
		break;
	}
}

==> antiright-3.0.tar.bz2: antiright-3.0/gtkshell/updated_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

static void
gsh_test_updating(struct GSH * gsh)
{
	ARPASSERT(gsh);
	if((gsh->bflags & GSH_UPDATING) != GSH_UPDATING)
	{
		gsh_start_updates(gsh);
		gsh->bflags |= GSH_UPDATING;
	}

}

static void
gsh_updater_argument_generic(struct GSH * gsh, int argc, int *counter)
{
	gsh_count(argc, counter);
	gsh_test_updating(gsh);
}

static void
add_updater(struct GSH * gsh, int argc, int * counter, char **argv,
		   void (*add_func)(struct GSH *, const gchar *))
{
#ifdef DEBUG
	ARBUG("add_updater()");
#endif /* DEBUG */

	(*add_func)(gsh, (const gchar *)argv[*counter+1]);
	gsh_updater_argument_generic(gsh, argc, counter);
}

void
gsh_handle_updated_arguments(struct GSH * gsh, int argc,
			     char **argv, int *counter)
{
	g_assert(strlen(argv[(*counter)]) > 2);
	switch (argv[(*counter)][3])
	{
	case 'l':
		add_updater(gsh, argc, counter, argv,
			    &gsh_add_updated_label);
		break;
	case 'p':
		add_updater(gsh, argc, counter, argv,
			    &gsh_add_updated_progress);
		break;
	}
}
